#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MINIMUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MINIMUM_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/minimum.hpp>

#endif
